@@ -2,16 +2,16 @@
 # New S3 methods
 
 #' Get model response
-#' 
-#' Extract the response of a fitted model 
-#' 
+#'
+#' Extract the response of a fitted model
+#'
 #' The purpose of this function is to savely extract the response (dependent variable) of the fitted model classes
-#' 
+#'
 #' @param object a fitted model
-#' @param ... additional parameters 
-#' 
+#' @param ... additional parameters
+#'
 #' @example inst/examples/wrappersHelp.R
-#' 
+#'
 #' @seealso \code{\link{getRefit}}, \code{\link{getSimulations}}, \code{\link{getFixedEffects}}, \code{\link{getFitted}}
 #' @author Florian Hartig
 #' @export
@@ -22,43 +22,51 @@ getObservedResponse <- function (object, ...) {
 #' @rdname getObservedResponse
 #' @export
 getObservedResponse.default <- function (object, ...){
-  out = model.frame(object)[,1] 
+  out = model.frame(object)[,1]
 
   # check for weights in k/n case
   if(family(object)$family %in% c("binomial", "betabinomial") & "(weights)" %in% colnames(model.frame(object))){
     x = model.frame(object)
     out = out * x$`(weights)`
   }
-    
+
   # check for k/n binomial
   if(is.matrix(out)){
     if(!(ncol(out) == 2)) securityAssertion("nKcase - wrong dimensions of response")
     if(!(family(object)$family %in% c("binomial", "betabinomial"))) securityAssertion("nKcase - wrong family")
 
     out = out[,1]
-  } 
-  
+  }
+
   # observation is factor - unlike lme4 and older, glmmTMB simulates nevertheless as numeric
   if(is.factor(out)) out = as.numeric(out) - 1
 
   return(out)
 }
 
+weightsWarning = "Model was fit with prior weights. These will be ignored in the simulation. See ?getSimulations for details"
+
 #' Get model simulations
-#' 
+#'
 #' Wrapper to simulate from a fitted model
-#' 
-#' The purpose of this wrapper for for the simulate function is to standardize the simulations from a model in a standardized way
-#' 
+#'
+#' The purpose of this wrapper for for the simulate function is to return the simulations from a model in a standardized way
+#'
 #' @param object a fitted model
 #' @param nsim number of simulations
 #' @param type if simulations should be prepared for getQuantile or for refit
 #' @param ... additional parameters to be passed on, usually to the simulate function of the respective model class
-#' 
+#'
 #' @return a matrix with simulations
 #' @example inst/examples/wrappersHelp.R
-#' 
+#'
 #' @seealso \code{\link{getObservedResponse}}, \code{\link{getRefit}}, \code{\link{getFixedEffects}}, \code{\link{getFitted}}
+#'
+#' @details The function is a wrapper for for the simulate function is to return the simulations from a model in a standardized way.
+#'
+#' Note: if the model was fit with weights, the function will throw a warning if used with a model class whose simulate function does not include the weightsi in the simulations. Note that the results may or may not be appropriate in this case, depending on how you use the weights.
+#'
+#'
 #' @author Florian Hartig
 #' @export
 getSimulations <- function (object, nsim = 1 , type = c("normal", "refit"), ...) {
@@ -68,57 +76,54 @@ getSimulations <- function (object, nsim = 1 , type = c("normal", "refit"), ...)
 #' @rdname getSimulations
 #' @export
 getSimulations.default <- function (object, nsim = 1, type = c("normal", "refit"), ...){
-  
+
   type <- match.arg(type)
-  
+
   out = simulate(object, nsim = nsim , ...)
-  
+
   if (type == "normal"){
     if(family(object)$family %in% c("binomial", "betabinomial")){
       if("(weights)" %in% colnames(model.frame(object))){
         x = model.frame(object)
         out = out * x$`(weights)`
-      } else if (is.matrix(out[[1]])){ 
+      } else if (is.matrix(out[[1]])){
         # this is for the k/n binomial case
         out = as.matrix(out)[,seq(1, (2*nsim), by = 2)]
       } else if(is.factor(out[[1]])){
         if(nlevels(out[[1]]) != 2){
           warning("The fitted model has a factorial response with number of levels not equal to 2 - there is currently no sensible application in DHARMa that would lead to this situation. Likely, you are trying something that doesn't work.")
-        } 
+        }
         else{
           out = data.matrix(out) - 1
         }
-      } 
-    } 
-    
+      }
+    }
+
     if(!is.matrix(out)) out = data.matrix(out)
   } else{
     if(family(object)$family %in% c("binomial", "betabinomial")){
       if (!is.matrix(out[[1]]) & !is.numeric(out)) data.frame(data.matrix(out)-1)
     }
   }
-  
+
   return(out)
 }
 
 
-#' @importFrom lme4 refit
-#' @importFrom lme4 fixef 
-NULL
-
-
 #' Extract fixed effects of a supported model
-#' 
+#'
 #' A wrapper to extract fixed effects of a supported model
-#' 
+#'
 #' @param fittedModel a fitted model
-#' 
+#'
 #' @example inst/examples/wrappersHelp.R
-#' 
+#'
+#' @importFrom lme4 fixef
+#'
 #' @seealso \code{\link{getObservedResponse}}, \code{\link{getSimulations}}, \code{\link{getRefit}}, \code{\link{getFitted}}
 #' @export
 getFixedEffects <- function(fittedModel){
-  
+
   if(class(fittedModel)[1] %in% c("glm", "lm", "gam", "bam", "negbin") ){
     out  = coef(fittedModel)
   } else if(class(fittedModel)[1] %in% c("glmerMod", "lmerMod", "HLfit")){
@@ -134,17 +139,17 @@ getFixedEffects <- function(fittedModel){
 }
 
 #' Get model refit
-#' 
+#'
 #' Wrapper to refit a fitted model
-#' 
+#'
 #' @param object a fitted model
 #' @param newresp the new response that should be used to refit the model
 #' @param ... additional parameters to be passed on to the refit or update class that is used to refit the model
-#' 
+#'
 #' @details The purpose of this wrapper is to standardize the refit of a model. The behavior of this function depends on the supplied model. When available, it uses the refit method, otherwise it will use update. For glmmTMB: since version 1.0, glmmTMB has a refit function, but this didn't work, so I switched back to this implementation, which is a hack based on the update function.
-#' 
+#'
 #' @example inst/examples/wrappersHelp.R
-#' 
+#'
 #' @seealso \code{\link{getObservedResponse}}, \code{\link{getSimulations}}, \code{\link{getFixedEffects}}
 #' @author Florian Hartig
 #' @export
@@ -153,25 +158,27 @@ getRefit <- function (object, newresp, ...) {
 }
 
 #' @rdname getRefit
+#'
+#' @importFrom lme4 refit
+#'
 #' @export
 getRefit.default <- function (object, newresp, ...){
   refit(object, newresp, ...)
 }
 
-
 #' Get model fitted
-#' 
+#'
 #' Wrapper to get the fitted value a fitted model
-#' 
-#' The purpose of this wrapper is to standardize extract the fitted values 
-#' 
+#'
+#' The purpose of this wrapper is to standardize extract the fitted values
+#'
 #' @param object a fitted model
 #' @param ... additional parameters to be passed on, usually to the simulate function of the respective model class
-#' 
+#'
 #' @example inst/examples/wrappersHelp.R
-#' 
+#'
 #' @seealso \code{\link{getObservedResponse}}, \code{\link{getSimulations}}, \code{\link{getRefit}}, \code{\link{getFixedEffects}}
-#' 
+#'
 #' @author Florian Hartig
 #' @export
 getFitted <- function (object, ...) {
@@ -184,44 +191,31 @@ getFitted.default <- function (object,...){
   fitted(object, ...)
 }
 
-#' Check weights
-#' 
-#' Checks if a model was fit with the weight argument
-#' 
-#' The purpose of this function is to check if a model was fit with the weights
-#' 
+#' has NA
+#'
+#' checks if the fitted model excluded NA values
+#'
 #' @param object a fitted model
-#' @param ... additional parameters 
-#' 
-#' @author Florian Hartig
+#'
+#' @details Checks if the fitted model excluded NA values
+#'
 #' @export
-hasWeigths <- function (object, ...) {
-  UseMethod("hasWeigths", object)
-}
-
-#' @export
-hasWeigths.default <- function (object, ...){
-  if("(weights)" %in% colnames(model.frame(object))) return(TRUE)
-  else (return(FALSE))
-}
-
-
-hasNA <- function(fittedModel){
-  x = rownames(model.frame(fittedModel))
-  if(length(x) < as.numeric(x[length(x) ])) return(TRUE)
-  else return(FALSE)
-}
 
 
+# hasNA <- function(object){
+#   x = rownames(model.frame(object))
+#   if(length(x) < as.numeric(x[length(x) ])) return(TRUE)
+#   else return(FALSE)
+# }
 
 ######### LM #############
 
 #' @rdname getRefit
 #' @export
 getRefit.lm <- function(object, newresp, ...){
-  
-  newData <-model.frame(object)  
-  
+
+  newData <-model.frame(object)
+
   if(is.vector(newresp)){
     newData[,1] = newresp
   } else if (is.factor(newresp)){
@@ -231,8 +225,8 @@ getRefit.lm <- function(object, newresp, ...){
     # Hack to make the binomial n/k case work
     newData[[1]] = NULL
     newData = cbind(newresp, newData)
-  }     
-  
+  }
+
   refittedModel = update(object, data = newData)
   return(refittedModel)
 }
@@ -246,6 +240,12 @@ hasWeigths.lm <- function(object, ...){
 
 ######### GLM #############
 
+#' @rdname getSimulations
+#' @export
+getSimulations.negbin<- function (object, nsim = 1, type = c("normal", "refit"), ...){
+  if("(weights)" %in% colnames(model.frame(object))) warning(weightsWarning)
+  getSimulations.default(object = object, nsim = nsim, type = type, ...)
+}
 
 
 ######## MGCV ############
@@ -265,20 +265,31 @@ getFitted.gam <- function(object, ...){
 # plot(fitted(fittedModelGAM), predict(fittedModelGAM, type = "response"))
 
 
+######## lme4 ############
+
+
+#' @rdname getSimulations
+#' @export
+getSimulations.lmerMod <- function (object, nsim = 1, type = c("normal", "refit"), ...){
+
+  if("(weights)" %in% colnames(model.frame(object))) warning(weightsWarning)
+  getSimulations.default(object = object, nsim = nsim, type = type, ...)
+}
+
 
 ######## glmmTMB ######
 
 #' @rdname getRefit
 #' @export
 getRefit.glmmTMB <- function(object, newresp, ...){
-  newData <-model.frame(object)    
-  
+  newData <-model.frame(object)
+
   # hack to make update work - for some reason, glmmTMB wants the matrix embedded in the df for update to work  ... should be solved ideally, see https://github.com/glmmTMB/glmmTMB/issues/549
   if(is.matrix(newresp)){
     tmp = colnames(newData[[1]])
     newData[[1]] = NULL
     newData = cbind(newresp, newData)
-    colnames(newData)[1:2] = tmp    
+    colnames(newData)[1:2] = tmp
   } else {
     newData[[1]] = newresp
   }
@@ -293,19 +304,21 @@ getRefit.glmmTMB <- function(object, newresp, ...){
 #' @rdname getSimulations
 #' @export
 getSimulations.glmmTMB <- function (object, nsim = 1, type = c("normal", "refit"), ...){
-  
+
+  if("(weights)" %in% colnames(model.frame(object)) & ! family(object)$family %in% c("binomial", "betabinomial")) warning(weightsWarning)
+
   type <- match.arg(type)
-  
+
   out = simulate(object, nsim = nsim, ...)
-  
+
   if (type == "normal"){
-    if (is.matrix(out[[1]])){ 
+    if (is.matrix(out[[1]])){
       # this is for the k/n binomial case
       out = as.matrix(out)[,seq(1, (2*nsim), by = 2)]
-    } 
+    }
     if(!is.matrix(out)) out = data.matrix(out)
   }else{
-    
+
     # check for weights in k/n case
     if(family(object)$family %in% c("binomial", "betabinomial")){
       if("(weights)" %in% colnames(model.frame(object))){
@@ -319,14 +332,14 @@ getSimulations.glmmTMB <- function (object, nsim = 1, type = c("normal", "refit"
         out = as.data.frame(as.matrix(out)[,seq(1, (2*nsim), by = 2)])
       }
     }
-       
-       
-       
 
-    
-    
-    # matrixResp = 
-    # 
+
+
+
+
+
+    # matrixResp =
+    #
     # if(matrixResp & !is.null(ncol(newresp))){
     #   # Hack to make the factor binomial case work
     #   tmp = colnames(newData[[1]])
@@ -336,15 +349,15 @@ getSimulations.glmmTMB <- function (object, nsim = 1, type = c("normal", "refit"
     # } else if(!is.null(ncol(newresp))){
     #   newData[[1]] = newresp[,1]
     # } else {
-    #   newData[[1]] = newresp 
+    #   newData[[1]] = newresp
     # }
-    
-    
-    # if (out$modelClass == "glmmTMB" & ncol(simulations) == 2*n) simObserved = simulations[,(1+(2*(i-1))):(2+(2*(i-1)))]    
+
+
+    # if (out$modelClass == "glmmTMB" & ncol(simulations) == 2*n) simObserved = simulations[,(1+(2*(i-1))):(2+(2*(i-1)))]
   }
-  
+
   # else securityAssertion("Simulation results produced unsupported data structure", stop = TRUE)
-  
+
   return(out)
 }
 
@@ -352,9 +365,8 @@ getSimulations.glmmTMB <- function (object, nsim = 1, type = c("normal", "refit"
 
 #' @rdname getObservedResponse
 #' @export
-#' @importFrom spaMM response 
 getObservedResponse.HLfit <- function(object, ...){
-  out = response(object, ...)
+  out = spaMM::response(object, ...)
 
   nKcase = is.matrix(out)
   if(nKcase){
@@ -362,11 +374,11 @@ getObservedResponse.HLfit <- function(object, ...){
     if(! (ncol(out)==2)) securityAssertion("nKcase - wrong dimensions of response")
     out = out[,1]
   }
-  
-  if(!is.numeric(out)) out = as.numeric(out) 
-  
+
+  if(!is.numeric(out)) out = as.numeric(out)
+
   return(out)
-  
+
 }
 
 #' @rdname getSimulations
@@ -374,9 +386,9 @@ getObservedResponse.HLfit <- function(object, ...){
 getSimulations.HLfit <- function(object, nsim = 1, type = c("normal", "refit"), ...){
 
   type <- match.arg(type)
-  
+
   capture.output({out = simulate(object, nsim = nsim, ...)})
-  
+
   if(type == "normal"){
     if(!is.matrix(out)) out = data.matrix(out)
   }else{
@@ -387,16 +399,7 @@ getSimulations.HLfit <- function(object, nsim = 1, type = c("normal", "refit"),
 
 #' @rdname getRefit
 #' @export
-#' @importFrom spaMM update_resp 
 getRefit.HLfit <- function(object, newresp, ...) {
-  update_resp(object, newresp, evaluate = TRUE)
+  spaMM::update_resp(object, newresp, evaluate = TRUE)
 }
 
-#' @export
-hasWeigths.HLfit <- function(object, ...){
-  if(length(unique(object$prior.weights)) != 1) return(TRUE)
-  else return(FALSE)
-}
-
-
-
