@@ -1,69 +1,71 @@
 #' Create simulated residuals
-#' 
-#' The function creates scaled residuals by simulating from the fitted model
+#'
+#' The function creates scaled residuals by simulating from the fitted model. Residuals can be extracted with \code{\link{residuals.DHARMa}}. See \code{\link{testResiduals}} for an overview of residual tests, \code{\link{plot.DHARMa}} for an overview of available plots.
+#'
 #' @param fittedModel a fitted model  of a class supported by DHARMa
-#' @param n number of simulations. Default is 100. A more save value would be 250 or even 1000. The smaller the number, the higher the stochastic error on the residuals. Also, for very small n, discretization artefacts can influence the tests. 
+#' @param n number of simulations. Default is 100. A more save value would be 250 or even 1000. The smaller the number, the higher the stochastic error on the residuals. Also, for very small n, discretization artefacts can influence the tests.
 #' @param refit if FALSE, new data will be simulated and scaled residuals will be created by comparing observed data with new data. If TRUE, the model will be refit on the simulated data (parametric bootstrap), and scaled residuals will be created by comparing observed with refitted residuals.
 #' @param integerResponse if TRUE, noise will be added at to the residuals to maintain a uniform expectations for integer responses (such as Poisson or Binomial). Usually, the model will automatically detect the appropriate setting, so there is no need to adjust this setting.
-#' @param plot if TRUE, \code{\link{plotSimulatedResiduals}} will be directly run after the simulations have terminated
+#' @param plot if TRUE, \code{\link{plotResiduals}} will be directly run after the residuals have been calculated
 #' @param ... parameters to pass to the simulate function of the model object. An important use of this is to specify whether simulations should be conditional on the current random effect estimates, e.g. via re.form. Note that not all models support syntax to specify conditionao or unconditional simulations. See also details
 #' @param seed the random seed to be used within DHARMa. The default setting, recommended for most users, is keep the random seed on a fixed value 123. This means that you will always get the same randomization and thus teh same result when running the same code. NULL = no new seed is set, but previous random state will be restored after simulation. FALSE = no seed is set, and random state will not be restored. The latter two options are only recommended for simulation experiments. See vignette for details.
+#' @param method the quantile randomization method used. The two options implemented at the moment are probability integral transform (PIT-) residuals (current default), and the "traditional" randomization procedure, that was used in DHARMa until version 0.3.0. For details, see \code{\link{getQuantile}}
 #' @return An S3 class of type "DHARMa", essentially a list with various elements. Implemented S3 functions include plot, print and \code{\link{residuals.DHARMa}}. Residuals returns the calculated scaled residuals.
-#' 
-#' @details There are a number of important considerations when simulating from a more complex (hierarchical) model: 
-#' 
-#' \strong{Re-simulating random effects / hierarchical structure}: in a hierarchical model, we have several stochastic processes aligned on top of each other. Specifically, in a GLMM, we have a lower level stochastic process (random effect), whose result enters into a higher level (e.g. Poisson distribution). For other hierarchical models such as state-space models, similar considerations apply. 
-#' 
+#'
+#' @details There are a number of important considerations when simulating from a more complex (hierarchical) model:
+#'
+#' \strong{Re-simulating random effects / hierarchical structure}: in a hierarchical model, we have several stochastic processes aligned on top of each other. Specifically, in a GLMM, we have a lower level stochastic process (random effect), whose result enters into a higher level (e.g. Poisson distribution). For other hierarchical models such as state-space models, similar considerations apply.
+#'
 #' In such a situation, we have to decide if we want to re-simulate all stochastic levels, or only a subset of those. For example, in a GLMM, it is common to only simulate the last stochastic level (e.g. Poisson) conditional on the fitted random effects. This is often referred to as a conditional simuation. For controlling how many levels should be re-simulated, the simulateResidual function allows to pass on parameters to the simulate function of the fitted model object. Please refer to the help of the different simulate functions (e.g. ?simulate.merMod) for details. For merMod (lme4) model objects, the relevant parameters are parameters are use.u and re.form
-#' 
-#' If the model is correctly specified, the simulated residuals should be flat regardless how many hierarchical levels we re-simulate. The most thorough procedure would therefore be to test all possible options. If testing only one option, I would recommend to re-simulate all levels, because this essentially tests the model structure as a whole. This is the default setting in the DHARMa package. A potential drawback is that re-simulating the lower-level random effects creates more variability, which may reduce power for detecting problems in the upper-level stochastic processes. In particular dispersion tests may produce different results when switching from conditional to unconditional simulations, and often the conditional simulation is more sensitive. 
-#' 
+#'
+#' If the model is correctly specified, the simulated residuals should be flat regardless how many hierarchical levels we re-simulate. The most thorough procedure would therefore be to test all possible options. If testing only one option, I would recommend to re-simulate all levels, because this essentially tests the model structure as a whole. This is the default setting in the DHARMa package. A potential drawback is that re-simulating the lower-level random effects creates more variability, which may reduce power for detecting problems in the upper-level stochastic processes. In particular dispersion tests may produce different results when switching from conditional to unconditional simulations, and often the conditional simulation is more sensitive.
+#'
 #' \strong{Integer responses}: a second complication is the treatment of inter responses. Imaging we have observed a 0, and we predict 30\% zeros - what is the quantile that we should display for the residual? To deal with this problem and maintain a uniform response, the option integerResponse adds a uniform noise from -0.5 to 0.5 on the simulated and observed response, which creates a uniform distribution - you can see this via hist(ecdf(runif(10000))(runif(10000))).
-#' 
-#'  DHARMa will try to automatically if the fitted model has an integer or discrete distribution via the family argument. However, in some cases the family does not allow to uniquely identify the distribution type. For example, a tweedie distribution can be inter or continuous. Therefore, DHARMa will additionally check the simulation results for repeated values, and will change the distribution type if repeated values are found (a message is displayed in this case). 
-#' 
+#'
+#'  DHARMa will try to automatically if the fitted model has an integer or discrete distribution via the family argument. However, in some cases the family does not allow to uniquely identify the distribution type. For example, a tweedie distribution can be inter or continuous. Therefore, DHARMa will additionally check the simulation results for repeated values, and will change the distribution type if repeated values are found (a message is displayed in this case).
+#'
 #' \strong{Refitting or not}: a third issue is how residuals are calculated. simulateResiduals has two options that are controlled by the refit parameter:
-#' 
+#'
 #' 1. if refit = FALSE (default), new data is simulated from the fitted model, and residuals are calculated by comparing the observed data to the new data
-#' 
-#' 2. if refit = TRUE, a parametric bootstrap is performed, meaning that the model is refit on the new data, and residuals are created by comparing observed residuals against refitted residuals 
-#' 
+#'
+#' 2. if refit = TRUE, a parametric bootstrap is performed, meaning that the model is refit on the new data, and residuals are created by comparing observed residuals against refitted residuals
+#'
 #' The second option is much slower, and only important for running tests that rely on comparing observed to simulated residuals, e.g. the  \code{\link{testOverdispersion}} function
-#' 
+#'
 #' \strong{Residuals per group}: In many situations, it can be useful to look at residuals per group, e.g. to see how much the model over / underpredicts per plot, year or subject. To do this, use \code{\link{recalculateResiduals}}, together with a grouping variable (see also help)
-#' 
-#' \strong{Transformation to other distributions}: DHARMa calculates residuals for which the theoretical expectation (assuming a correctly specified model) is uniform. To transfor this residuals to another distribution (e.g. so that a correctly specified model will have normal residuals) see \code{\link{residuals.DHARMa}}. 
-#' 
-#' @note See \code{\link{testResiduals}} for an overview of residual tests, \code{\link{plot.DHARMa}} for an overview of available plots. 
-#' 
-#' @seealso \code{\link{testResiduals}}, \code{\link{plot.DHARMa}}, \code{\link{print.DHARMa}}, \code{\link{residuals.DHARMa}}, \code{\link{recalculateResiduals}}
-#' 
+#'
+#' \strong{Transformation to other distributions}: DHARMa calculates residuals for which the theoretical expectation (assuming a correctly specified model) is uniform. To transfor this residuals to another distribution (e.g. so that a correctly specified model will have normal residuals) see \code{\link{residuals.DHARMa}}.
+#'
+#' @seealso \code{\link{testResiduals}}, \code{\link{plot.DHARMa}}, \code{\link{plotResiduals}}, \code{\link{print.DHARMa}}, \code{\link{residuals.DHARMa}}, \code{\link{recalculateResiduals}}
+#'
+#'
 #' @example inst/examples/simulateResidualsHelp.R
 #' @import stats
 #' @export
-simulateResiduals <- function(fittedModel, n = 250, refit = F, integerResponse = NULL, plot = F, seed = 123, ...){
+simulateResiduals <- function(fittedModel, n = 250, refit = F, integerResponse = NULL, plot = F, seed = 123, method = c("PIT", "traditional"), ...){
 
   ######## general assertions and startup calculations ##########
-  
+
   if (n < 2) stop("error in DHARMa::simulateResiduals: n > 1 is required to calculate scaled residuals")
-  checkModel(fittedModel)  
+  checkModel(fittedModel)
+  match.arg(method)
   randomState <-getRandomState(seed)
   on.exit({randomState$restoreCurrent()})
-  ptm <- proc.time() 
+  ptm <- proc.time()
 
   ####### extract model info ############
-  
+
   out = list()
-  
+
   family = family(fittedModel)
   out$fittedModel = fittedModel
   out$modelClass = class(fittedModel)[1]
-  
+
   out$nObs = nobs(fittedModel)
   out$nSim = n
   out$refit = refit
-  out$observedResponse = getObservedResponse(fittedModel) 
-  
+  out$observedResponse = getObservedResponse(fittedModel)
+
   if(is.null(integerResponse)){
     if (family$family %in% c("binomial", "poisson", "quasibinomial", "quasipoisson", "Negative Binom", "nbinom2", "nbinom1", "genpois", "compois", "truncated_poisson", "truncated_nbinom2", "truncated_nbinom1", "betabinomial", "Poisson", "Tpoisson", "COMPoisson", "negbin", "Tnegbin") | grepl("Negative Binomial",family$family) ) integerResponse = TRUE
     else integerResponse = FALSE
@@ -73,51 +75,51 @@ simulateResiduals <- function(fittedModel, n = 250, refit = F, integerResponse =
   out$problems = list()
 
   # re-form should be set to ~0 to avoid spurious residual patterns, see https://github.com/florianhartig/DHARMa/issues/43
-    
+
   if(out$modelClass %in% c("HLfit")){
-    out$fittedPredictedResponse = predict(fittedModel, type = "response", re.form = ~0)[,1L] 
+    out$fittedPredictedResponse = predict(fittedModel, type = "response", re.form = ~0)[,1L]
   }else{
-    out$fittedPredictedResponse = predict(fittedModel, type = "response", re.form = ~0) 
+    out$fittedPredictedResponse = predict(fittedModel, type = "response", re.form = ~0)
   }
-  
+
   out$fittedFixedEffects = getFixedEffects(fittedModel)
   out$fittedResiduals = residuals(fittedModel, type = "response")
-  
-  ######## refit = F ################## 
+
+  ######## refit = F ##################
 
   if (refit == FALSE){
-    
-    out$simulatedResponse = getSimulations(fittedModel, nsim = n, type = "normal", ...)
-    
-    checkSimulations(out$simulatedResponse, out$nObs, out$nSim)
-    
-    out$scaledResiduals = getQuantile(simulations = out$simulatedResponse , observed = out$observedResponse , n = out$nObs, nSim = out$nSim, integerResponse = integerResponse)
 
-  ######## refit = T ################## 
+    out$simulatedResponse = getSimulations(fittedModel, nsim = n, type = "normal", ...)
+
+    checkSimulations(out$simulatedResponse, out$nObs, out$nSim)
+
+    out$scaledResiduals = getQuantile(simulations = out$simulatedResponse , observed = out$observedResponse , integerResponse = integerResponse, method = method)
+
+  ######## refit = T ##################
   } else {
 
     # Adding new outputs
 
-    out$refittedPredictedResponse <- matrix(nrow = out$nObs, ncol = n )  
-    out$refittedFixedEffects <- matrix(nrow = length(out$fittedFixedEffects), ncol = n )  
-    #out$refittedRandomEffects <- matrix(nrow = length(out$fittedRandomEffects), ncol = n )  
-    out$refittedResiduals = matrix(nrow = out$nObs, ncol = n)   
-    out$refittedPearsonResiduals = matrix(nrow = out$nObs, ncol = n)   
-    
+    out$refittedPredictedResponse <- matrix(nrow = out$nObs, ncol = n )
+    out$refittedFixedEffects <- matrix(nrow = length(out$fittedFixedEffects), ncol = n )
+    #out$refittedRandomEffects <- matrix(nrow = length(out$fittedRandomEffects), ncol = n )
+    out$refittedResiduals = matrix(nrow = out$nObs, ncol = n)
+    out$refittedPearsonResiduals = matrix(nrow = out$nObs, ncol = n)
+
     out$simulatedResponse = getSimulations(fittedModel, nsim = n, type = "refit", ...)
-    
+
     for (i in 1:n){
 
       simObserved = out$simulatedResponse[[i]]
-  
+
       try({
-        
+
         # for testing
         # if (i==3) stop("x")
         # Note: also set silent = T for production
-    
+
         refittedModel = getRefit(fittedModel, simObserved)
-        
+
         out$refittedPredictedResponse[,i] = predict(refittedModel, type = "response")
         out$refittedFixedEffects[,i] = getFixedEffects(refittedModel)
         out$refittedResiduals[,i] = residuals(refittedModel, type = "response")
@@ -125,26 +127,26 @@ simulateResiduals <- function(fittedModel, n = 250, refit = F, integerResponse =
         #out$refittedRandomEffects[,i]  = ranef(refittedModel)
       }, silent = TRUE)
     }
-    
+
     ######### residual checks ###########
 
     if(anyNA(out$refittedResiduals)) warning("DHARMa::simulateResiduals warning: on refit = TRUE, at least one of the refitted models produced an error. Inspect the refitted model values. Results may not be reliable.")
-    
+
     ## check for convergence problems
-    
+
     dup = sum(duplicated(out$refittedFixedEffects, MARGIN = 2))
     if (dup > 0){
       if (dup < n/3){
         warning(paste("There were", dup, "of", n ,"duplicate parameter estimates in the refitted models. This may hint towards a problem with optimizer convergence in the fitted models. Results may not be reliable. The suggested action is to not use the refitting procedure, and diagnose with tools available for the normal (not refitted) simulated residuals. If you absolutely require the refitting procedure, try changing tolerance / iterations in the optimizer settings."))
       } else {
         warning(paste("There were", dup, "of", n ,"duplicate parameter estimates in the refitted models. This may hint towards a problem with optimizer convergence in the fitted models. Results are likely not reliable. The suggested action is to not use the refitting procedure, and diagnose with tools available for the normal (not refitted) simulated residuals. If you absolutely require the refitting procedure, try changing tolerance / iterations in the optimizer settings."))
-        out$problems[[length(out$problems)+ 1]] = "error in refit" 
+        out$problems[[length(out$problems)+ 1]] = "error in refit"
       }
-    } 
-    
+    }
+
     ######### residual calculations ###########
 
-    out$scaledResiduals = getQuantile(simulations = out$refittedResiduals, observed = out$fittedResiduals, n = out$nObs, nSim = out$nSim, integerResponse = integerResponse)
+    out$scaledResiduals = getQuantile(simulations = out$refittedResiduals, observed = out$fittedResiduals, integerResponse = integerResponse, method = method)
   }
 
   ########### Wrapup ############
@@ -153,42 +155,44 @@ simulateResiduals <- function(fittedModel, n = 250, refit = F, integerResponse =
   out$randomState = randomState
 
   class(out) = "DHARMa"
-  
+
   if(plot == TRUE) plot(out)
-  
+
   return(out)
 }
 
-getPossibleModels<-function()c("lm", "glm", "negbin", "lmerMod", "glmerMod", "gam", "bam", "glmmTMB", "HLfit") 
+getPossibleModels<-function()c("lm", "glm", "negbin", "lmerMod", "glmerMod", "gam", "bam", "glmmTMB", "HLfit")
+
+
 
 #' Check if the fitted model is supported by DHARMa
-#' 
-#' The function checks if the fitted model is supported by DHARMa, and if there are other issues, for example the use of weights, that could create problems for calculating quantile residuals
-#' 
-#' @param fittedModel a fitted model 
-#' @param stop whether to throw an error if the model is not supported by DHARMa  
-#' 
-#' @details The main purpose of this function os to check if the fitted model class is supported by DHARMa. The function additionally checks for properties of the fitted model that could create problems for calculating residuals or working with the resuls in DHARMa. At the moment, two such issues are checked
-#' 
-#' 1) Use of weights: most regression models in R support the use of the weights argument. Unfortunately, the argument means different things, depending on the context. In many situations, weights basically reweights the likelihood. In this case, simulated quantile residuals cannot be used, because the weighting
-#' 
-#' 2) NA values in the data: checkModel will detect if there were NA values in the data frame. For NA values, most regression models will remove the entire observation from the data. This is not a problem for DHARMa - residuals are then only calculated for non-NA rows in the data. However, if you provide additional predictors to DHARMa, for example to plot residuals against a predictor, you will have to remove all NA rows that were also removed in the model, otherwise the lengths of the vectors will not match. 
-#' 
-#' 
+#'
+#' The function checks if the fitted model is supported by DHARMa, and if there are other issues that could create problems
+#'
+#' @param fittedModel a fitted model
+#' @param stop whether to throw an error if the model is not supported by DHARMa
+#'
+#' @details The main purpose of this function os to check if the fitted model class is supported by DHARMa. The function additionally checks for properties of the fitted model that could create problems for calculating residuals or working with the resuls in DHARMa.
+#'
+#'
 #' @keywords internal
 checkModel <- function(fittedModel, stop = F){
-  
+
   out = T
-  
+
   if(!(class(fittedModel)[1] %in% getPossibleModels())){
     if(stop == FALSE) warning("DHARMa: fittedModel not in class of supported models. Absolutely no guarantee that this will work!")
-    else stop("DHARMa: fittedModel not in class of supported models") 
-  } 
-  
-  # if(hasWeigths(fittedModel)) warning("Your fitted model includes weights. For many GLMs, weights are not included in the simulations, and simulated quantile residuals are therefore not reliable. See ?checkModel for details")
-  
+    else stop("DHARMa: fittedModel not in class of supported models")
+  }
+
   # if(hasNA(fittedModel)) message("It seems there were NA values in the data used for fitting the model. This can create problems if you supply additional data to DHARMa functions. See ?checkModel for details")
-  
+
+  # TODO: check as implemented does not work reliably, check if there is any other option to check for NA
+  # #' @example inst/examples/checkModelHelp.R
+
+  #  NA values in the data: checkModel will detect if there were NA values in the data frame. For NA values, most regression models will remove the entire observation from the data. This is not a problem for DHARMa - residuals are then only calculated for non-NA rows in the data. However, if you provide additional predictors to DHARMa, for example to plot residuals against a predictor, you will have to remove all NA rows that were also removed in the model. For most models, you can get the rows of the data that were actually used in the fit via rownames(model.frame(fittedModel))
+
+
   if (class(fittedModel)[1] == "gam" ) if (class(fittedModel$family)[1] == "extended.family") stop("It seems you are trying to fit a model from mgcv that was fit with an extended.family. Simulation functions for these families are not yet implemented in DHARMa. See issue https://github.com/florianhartig/DHARMa/issues/11 for updates about this")
 
 }
@@ -196,86 +200,86 @@ checkModel <- function(fittedModel, stop = F){
 
 
 #' Check simulated data
-#' 
+#'
 #' The function checks if the simulated data seems fine
-#' 
+#'
 #' @param simulatedResponse the simulated response
 #' @param nObs number of observations
 #' @param nSim number of simulations
-#' 
+#'
 #' @keywords internal
 checkSimulations <- function(simulatedResponse, nObs, nSim){
-  
+
   if(!inherits(simulatedResponse, "matrix")) securityAssertion("Simulation from the model produced wrong class", stop = T)
-  
+
   if(any(dim(simulatedResponse) != c(nObs, nSim) )) securityAssertion("Simulation from the model produced wrong dimension", stop = T)
-  
+
   if(any(!is.finite(simulatedResponse))) message("Simulations from your fitted model produce infinite values. Consider if this is sensible")
-  
+
   if(any(is.nan(simulatedResponse))) securityAssertion("Simulations from your fitted model produce NaN values. DHARMa cannot calculated residuals for this. This is nearly certainly an error of the regression package you are using", stop = T)
   if(any(is.na(simulatedResponse))) securityAssertion("Simulations from your fitted model produce NA values. DHARMa cannot calculated residuals for this. This is nearly certainly an error of the regression package you are using", stop = T)
-  
+
 }
 
 
 
 
 #' Recalculate residuals with grouping
-#' 
+#'
 #' The purpose of this function is to recalculate scaled residuals per group, based on the simulations done by \code{\link{simulateResiduals}}
 #'
 #' @param simulationOutput an object with simulated residuals created by \code{\link{simulateResiduals}}
 #' @param group group of each data point
-#' @param aggregateBy function for the aggregation. Default is sum. This should only be changed if you know what you are doing. Note in particular that the expected residual distribution might not be flat any more if you choose general functions, such as sd etc. 
+#' @param aggregateBy function for the aggregation. Default is sum. This should only be changed if you know what you are doing. Note in particular that the expected residual distribution might not be flat any more if you choose general functions, such as sd etc.
 #' @param seed the random seed to be used within DHARMa. The default setting, recommended for most users, is keep the random seed on a fixed value 123. This means that you will always get the same randomization and thus teh same result when running the same code. NULL = no new seed is set, but previous random state will be restored after simulation. FALSE = no seed is set, and random state will not be restored. The latter two options are only recommended for simulation experiments. See vignette for details.
-#' 
-#' @return an object of class DHARMa, similar to what is returned by \code{\link{simulateResiduals}}, but with additional outputs for the new grouped calculations. Note that the relevant outputs are 2x in the object, the first is the grouped calculations (which is returned by $name access), and later another time, under identical name, the original output. Moreover, there is a function 'aggregateByGroup', which can be used to aggregate predictor variables in the same way as the variables calculated here 
-#' 
+#' @param method the quantile randomization method used. The two options implemented at the moment are probability integral transform (PIT-) residuals (current default), and the "traditional" randomization procedure, that was used in DHARMa until version 0.3.0. For details, see \code{\link{getQuantile}}
+#' @return an object of class DHARMa, similar to what is returned by \code{\link{simulateResiduals}}, but with additional outputs for the new grouped calculations. Note that the relevant outputs are 2x in the object, the first is the grouped calculations (which is returned by $name access), and later another time, under identical name, the original output. Moreover, there is a function 'aggregateByGroup', which can be used to aggregate predictor variables in the same way as the variables calculated here
+#'
 #' @example inst/examples/simulateResidualsHelp.R
 #' @export
-recalculateResiduals <- function(simulationOutput, group = NULL, aggregateBy = sum, seed = 123){
-  
+recalculateResiduals <- function(simulationOutput, group = NULL, aggregateBy = sum, seed = 123, method = c("PIT", "traditional")){
+
   randomState <-getRandomState(seed)
   on.exit({randomState$restoreCurrent()})
+  match.arg(method)
 
   if(!is.null(simulationOutput$original)) simulationOutput = simulationOutput$original
 
   out = list()
   out$original = simulationOutput
-  
+
   if(is.null(group)) return(simulationOutput)
   else group =as.factor(group)
   out$nGroups = nlevels(group)
 
   aggregateByGroup <- function(x) aggregate(x, by=list(group), FUN=aggregateBy)[,2]
-  
+
   out$observedResponse = aggregateByGroup(simulationOutput$observedResponse)
   out$fittedPredictedResponse = aggregateByGroup(simulationOutput$fittedPredictedResponse)
 
   if (simulationOutput$refit == F){
-    
+
     out$simulatedResponse = apply(simulationOutput$simulatedResponse, 2, aggregateByGroup)
-    out$scaledResiduals = getQuantile(simulations = out$simulatedResponse , observed = out$observedResponse , n = out$nGroups, nSim = simulationOutput$nSim, integerResponse = simulationOutput$integerResponse)
- 
-  ######## refit = T ##################   
+    out$scaledResiduals = getQuantile(simulations = out$simulatedResponse , observed = out$observedResponse , integerResponse = simulationOutput$integerResponse, method = method)
+
+  ######## refit = T ##################
   } else {
 
     out$refittedPredictedResponse <- apply(simulationOutput$refittedPredictedResponse, 2, aggregateByGroup)
     out$fittedResiduals = aggregateByGroup(simulationOutput$fittedResiduals)
     out$refittedResiduals = apply(simulationOutput$refittedResiduals, 2, aggregateByGroup)
     out$refittedPearsonResiduals = apply(simulationOutput$refittedPearsonResiduals, 2, aggregateByGroup)
-  
-    out$scaledResiduals = getQuantile(simulations = out$refittedResiduals , observed = out$fittedResiduals , n = out$nGroups, nSim = simulationOutput$nSim, integerResponse = simulationOutput$integerResponse)
+
+    out$scaledResiduals = getQuantile(simulations = out$refittedResiduals , observed = out$fittedResiduals , integerResponse = simulationOutput$integerResponse, method = method)
 
   }
-  
+
   # hack - the c here will result in both old and new outputs to be present resulting output, but a named access should refer to the new, grouped calculations
   # question to myself - what's the use of that, why not erase the old outputs? they are anyway saved in the old object
-  
+
   out$aggregateByGroup = aggregateByGroup
   out = c(out, simulationOutput)
   out$randomState = randomState
   class(out) = "DHARMa"
   return(out)
 }
-  
